from functools import wraps
from django.contrib.auth.decorators import login_required
from django.core.exceptions import PermissionDenied
from . import models

def mitarbeiter_in_erlaubnis(view_func):
    @login_required
    @wraps(view_func)
    def _wrapped_view(request, *args, **kwargs):
        if not models.ProjektZuweisung.objects.filter(
            nutzer_in=request.user,
            projekt__kostenstelle=kwargs.get('kostenstelle')
        ).exists():
            raise PermissionDenied
        return view_func(request, *args, **kwargs)
    return _wrapped_view

def projektleiter_in_erlaubnis(view_func):
    @login_required
    @wraps(view_func)
    def _wrapped_view(request, *args, **kwargs):
        if not models.ProjektLeiterIn.objects.filter(
            nutzer_in=request.user,
            leitet__kostenstelle=kwargs.get('kostenstelle')
        ).exists():
            raise PermissionDenied
        return view_func(request, *args, **kwargs)
    return _wrapped_view

def verwalter_in_erlaubnis(view_func):
    @login_required
    @wraps(view_func)
    def _wrapped_view(request, *args, **kwargs):
        if request.user.ist_verwalter:
            return view_func(request, *args, **kwargs)
        else:
            raise PermissionDenied
    return _wrapped_view