from django.urls import path
from django.contrib.auth.decorators import login_required
from . import views
from .decorators import mitarbeiter_in_erlaubnis, projektleiter_in_erlaubnis, verwalter_in_erlaubnis

app_name = 'arbeitszeit'
urlpatterns = [
    # MitarbeiterIn
    path(
        '',
        views.IndexView.as_view(),
        name='index'
    ),
    path(
        'hauptuebersicht/',
        login_required(views.HauptuebersichtView.as_view()),
        name='hauptuebersicht'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_mitarbeiter_in/',
        mitarbeiter_in_erlaubnis(views.MitarbeiterInFristAuswahlView.as_view()),
        name='mitarbeiter_in_fristauswahl'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_mitarbeiter_in/<int:frist>/',
        mitarbeiter_in_erlaubnis(views.MitarbeiterInStundenkontoView.as_view()),
        name='mitarbeiter_in_stundenkonto'
    ),
    # ProjektleiterIn
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/',
        projektleiter_in_erlaubnis(views.ProjektleiterInUebersichtView.as_view()),
        name='projektleiter_in_uebersicht'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/mitarbeiter_in_suchen/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInSuchen.as_view()),
        name='projekt_mitarbeiter_in_suchen'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/mitarbeiter_in_registrieren/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInRegistrierenView.as_view()),
        name='projekt_mitarbeiter_in_registrieren'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/' \
            'als_projektleiter_in/mitarbeiter_in_registrieren/erfolg/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInRegistrierenErfolgView.as_view()),
        name='projekt_mitarbeiter_in_registrieren_erfolg'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/' \
            'mitarbeiter_in_hinzufuegen/<int:nutzer_in>/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInHinzufuegenView.as_view()),
        name='projekt_mitarbeiter_in_hinzufuegen'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in' \
            'mitarbeiter_in_hinzufuegen/erfolg/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInHinzufuegenErfolgView.as_view()),
        name='projekt_mitarbeiter_in_hinzufuegen_erfolg'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/projektdaten_aendern/',
        projektleiter_in_erlaubnis(views.ProjektDatenAendernView.as_view()),
        name='projekt_daten_aendern'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/einrichtung_aendern/',
        projektleiter_in_erlaubnis(views.ProjektEinrichtungAuswahlView.as_view()),
        name='projektleiter_einrichtung_auswaehlen'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/' \
            'projektdaten_mitarbeiter_in_aendern/<int:pk>/',
        projektleiter_in_erlaubnis(views.ProjektMitarbeiterInAendernView.as_view()),
        name='projekt_mitarbeiter_in_aendern'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/stundenzettel/',
        projektleiter_in_erlaubnis(views.ProjektFristAuswahlView.as_view()),
        name='projekt_fristauswahl'
    ),
    path(
        'projektuebersicht/<int:kostenstelle>/als_projektleiter_in/stundenzettel/<int:frist>/',
        projektleiter_in_erlaubnis(views.ProjektStundenzettelView.as_view()),
        name='projekt_stundenzettel'
    ),
    # VerwalterIn
    path(
        'verwaltung/uebersicht/',
        verwalter_in_erlaubnis(views.VerwalterInUebersichtView.as_view()),
        name='verwalter_in_uebersicht'
    ),
    ## NutzerIn
    path(
        'verwaltung/nutzer_in_suche/',
        verwalter_in_erlaubnis(views.VerwalterNutzerInSucheView.as_view()),
        name='nutzer_in_suche'
    ),
    path(
        'verwaltung/nutzer_in/<int:pk>',
        verwalter_in_erlaubnis(views.VerwalterNutzerInDetailsView.as_view()),
        name='nutzer_in_details'
    ),
    path(
        'verwaltung/nutzer_in/<int:pk>/aendern/',
        verwalter_in_erlaubnis(views.VerwalterNutzerInAendernView.as_view()),
        name='nutzer_in_aendern'
    ),
    path(
        'verwaltung/nutzer_in_registrieren/',
        verwalter_in_erlaubnis(views.VerwalterNutzerInRegistrierenView.as_view()),
        name='nutzer_in_registrieren'
    ),
    path(
        'verwaltung/neue_nutzer_innen/',
        verwalter_in_erlaubnis(views.VerwalterNeueRNutzerInView.as_view()),
        name='neue_nutzer_innen'
    ),
    path(
        'verwalter/neue_nutzer_in/<int:pk>/ernuern/',
        verwalter_in_erlaubnis(views.VerwalterNeueRNutzerInErneuernView.as_view()),
        name='neue_nutzer_in_erneuern'
    ),
    ## Projekt
    path(
        'verwaltung/projekt_suche/',
        verwalter_in_erlaubnis(views.VerwalterProjektSucheView.as_view()),
        name='projekt_suche'
    ),
    path(
        'verwaltung/projekt_erstellen/',
        verwalter_in_erlaubnis(views.VerwalterProjektErstellenView.as_view()),
        name='projekt_erstellen'
    ),
    path(
        'verwaltung/projekt_einrichtung_auswaehlen/<int:kostenstelle>/',
        verwalter_in_erlaubnis(views.VerwalterProjektEinrichtungAuswahlView.as_view()),
        name='projekt_einrichtung_auswaehlen'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/',
        verwalter_in_erlaubnis(views.VerwalterProjektUebersichtView.as_view()),
        name='projekt_uebersicht'
    ),
    path(
        'verwaltung/projekt_aendern/<int:kostenstelle>/',
        verwalter_in_erlaubnis(views.VerwalterProjektAendernView.as_view()),
        name='projekt_aendern'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/projekt_leiter_in_suchen/',
        verwalter_in_erlaubnis(views.VerwalterProjektleiterInSuchen.as_view()),
        name='projekt_leiter_in_suchen'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/projekt_leiter_in_hinzufuegen/<int:nutzer_in_pk>/',
        verwalter_in_erlaubnis(views.VerwalterProjektleiterInHinzufuegen.as_view()),
        name='projekt_leiter_in_hinzufuegen'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/projekt_leiter_in_aendern/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterProjektleiterInAendern.as_view()),
        name='projekt_leiter_in_aendern'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/verwalter_projekt_mitarbeiter_in_suchen/',
        verwalter_in_erlaubnis(views.VerwalterMitarbeiterInSuchen.as_view()),
        name='verwalter_projekt_mitarbeiter_in_suchen'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/projekt_mitarbeiter_in_hinzufuegen/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterMitarbeiterInAendern.as_view()),
        name='verwaltung_projekt_mitarbeiter_in_hinzufuegen'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/projekt_mitarbeiter_in_aendern/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterMitarbeiterInAendern.as_view()),
        name='verwaltung_projekt_mitarbeiter_in_aendern'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/stundenzettel/',
        verwalter_in_erlaubnis(views.VerwalterProjektFristAuswahlView.as_view()),
        name='verwalter_projekt_fristauswahl'
    ),
    path(
        'verwaltung/projekt_uebersicht/<int:kostenstelle>/stundenzettel/<int:frist>/',
        verwalter_in_erlaubnis(views.VerwalterProjektStundenzettelView.as_view()),
        name='verwalter_projekt_stundenzettel'
    ),
    ## Einrichtung
    path(
        'verwaltung/einrichtungs_suche/',
        verwalter_in_erlaubnis(views.VerwalterEinrichtungsSucheView.as_view()),
        name='einrichtungs_suche'
    ),
    path(
        'verwaltung/einrichtung_erstellen/',
        verwalter_in_erlaubnis(views.VerwalterEinrichtungErstellenView.as_view()),
        name='einrichtung_erstellen'
    ),
    path(
        'verwaltung/einrichtung_aendern/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterEinrichtungAendernView.as_view()),
        name='einrichtung_aendern'
    ),
    path(
        'verwaltung/einrichtung_loeschen/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterEinrichtungLoeschenView.as_view()),
        name='einrichtung_loeschen'
    ),
    ## Gehaltsstufen
    path(
        'verwaltung/gehaltsstufen/',
        verwalter_in_erlaubnis(views.VerwalterGehaltsstufenView.as_view()),
        name='gehaltsstufen'
    ),
    path(
        'verwaltung/gehaltsstufe_erstellen/',
        verwalter_in_erlaubnis(views.VerwalterGehaltsstufeErstellenView.as_view()),
        name='gehaltsstufe_erstellen'
    ),
    path(
        'verwaltung/gehaltsstufe_aendern/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterGehaltsstufeAendernView.as_view()),
        name='gehaltsstufe_aendern'
    ),
    path(
        'verwaltung/gehaltsstufen_loeschen/<int:pk>/',
        verwalter_in_erlaubnis(views.VerwalterGehaltsstufeLoeschenView.as_view()),
        name='gehaltsstufe_loeschen'
    ),
    ## Fristen
    path(
        'verwalter/fristen/',
        verwalter_in_erlaubnis(views.VerwalterFristView.as_view()),
        name='fristen'
    ),
    path(
        'verwalter/fristen/<int:pk>/aendern/',
        verwalter_in_erlaubnis(views.VerwalterFristAendernView.as_view()),
        name='frist_aendern'
    ),
    path(
        'verwalter/systemnachrichten/',
        verwalter_in_erlaubnis(views.VerwalterSystemNachrichtenView.as_view()),
        name='systemnachrichten'
    ),
    path(
        'verwalter/systemachricht/<int:pk>/aendern/',
        verwalter_in_erlaubnis(views.VerwalterSystemNachrichtenAendernView.as_view()),
        name='systemnachricht_aendern'
    ),
    path(
        'verwalter/systemachricht/<int:pk>/loeschen/',
        verwalter_in_erlaubnis(views.VerwalterSystemNachrichtenLoeschenView.as_view()),
        name='systemnachricht_loeschen'
    ),
    path(
        'verwalter/systemachricht/erstellen/',
        verwalter_in_erlaubnis(views.VerwalterSystemNachrichtenErstellenView.as_view()),
        name='systemnachricht_erstellen'
    ),
]
