from django.views.generic import TemplateView, RedirectView, ListView
from django.db.models import Q
from functools import reduce
from django.http import JsonResponse
from .. import models
from .. import forms

class IndexView(TemplateView):
    template_name = 'arbeitszeit/index.html'

class HauptuebersichtView(TemplateView):
    template_name = 'arbeitszeit/hauptuebersicht.html'

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        context['mitarbeiter_in_zuweisung'] = models.ProjektZuweisung.objects.select_related(
            'projekt').filter(nutzer_in=self.request.user)
        context['projektleitungen'] = models.ProjektLeiterIn.objects.select_related(
            'leitet').filter(nutzer_in=self.request.user)

        return context

class FristAuswahlView(RedirectView):
    def get_redirect_url(self, *args, **kwargs):
        get_frist = self.request.GET.get('frist_auswahl')
        if get_frist is None:
            kwargs['frist'] = models.Frist.objects.first().pk
        else:
            kwargs['frist'] = get_frist
        return super().get_redirect_url(*args, **kwargs)

class SuchView(ListView):
    such_felder = None
    paginate_by = 25

    def get_suchfilter(self):
        if self.such_felder is None:
            raise ValueError('Keine Suchfelder angegeben.')
        suchform = forms.SuchForm(self.request.GET)
        if suchform.is_valid():
            such_parameter = suchform.cleaned_data.get('suchfeld').split(' ')
            such_filter = reduce(lambda q1, q2: q1 | q2, (
                Q(
                    **{feld + '__icontains' : str(parameter)}
                ) for feld in self.such_felder for parameter in such_parameter )
            )
        else:
            such_filter = Q(pk=None)
        return such_filter

    def get_queryset(self):
        return super().get_queryset().filter(self.get_suchfilter())

    def get(self, request):
        if request.content_type == 'application/json':
            vorschlaege_qset = self.get_queryset().values(*self.such_felder)[:20]
            vorschlaege = { 'vorschlaege': [' '.join(map(str, v.values())) for v in vorschlaege_qset] }
            return JsonResponse(vorschlaege)
        else:
            return super().get(request)

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context['suchform'] = forms.SuchForm()
        return context
