from django import forms
import django.contrib.auth.forms as auth_forms
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _
from . import models

class RegistrierungsForm(forms.ModelForm):
    class Meta:
        model = models.NutzerIn
        fields = ['email', 'vorname', 'nachname']

    def save(self, commit=True):
        email = models.NutzerIn.objects.normalize_email(
            self.cleaned_data('email')
        )
        nutzer_in = self.Meta.model(
            email=email,
            vorname=self.cleaned_data.get('vorname'),
            nachname=self.cleaned_data.get('nachname'),
            is_active=False,
            is_verwalter=False
        )
        nutzer_in.set_unusable_password()
        models.NeueRNutzerIn(nutzer_in=nutzer_in).save()
        if commit:
            nutzer_in.save()
        return nutzer_in

class RegistrierungsDatenBestaetigenForm(auth_forms.SetPasswordForm):
    vorname = forms.CharField(
        max_length=255
    )
    nachname = forms.CharField(
        max_length=255
    )

    def __init__(self, user, *args, **kwargs):
        initial = {
            'vorname' : user.vorname,
            'nachname' : user.nachname
        }
        kwargs['initial'] = initial
        super().__init__(user, *args, **kwargs)

    def clean(self):
        super().clean()
        if self.user.is_active:
            raise ValidationError(
                _("NutzerIn ist bereits aktiviert"),
                code='nutzerIn aktiv',
            )
        return self.cleaned_data

    def save(self, commit=True):
        self.user.vorname = self.cleaned_data.get('vorname')
        self.user.nachname = self.cleaned_data.get('nachname')
        self.user.is_active = True
        super().save(commit)
        return self.user

class ProfilAendernForm(forms.Form):
    vorname = forms.CharField(
        max_length=255
    )
    nachname = forms.CharField(
        max_length=255
    )
    passwort = forms.CharField(
        widget=forms.PasswordInput(),
        required=True
    )

    def __init__(self, user, *args, **kwargs):
        self.user = user
        initial = {
            'vorname' : user.vorname,
            'nachname' : user.nachname
        }
        kwargs['initial'] = initial
        super().__init__(*args, **kwargs)

    def clean_passwort(self):
        passwort = self.cleaned_data.get('passwort')
        if not self.user.check_password(passwort):
            raise ValidationError(
                _('Das eingegebene Passwort ist ungueltig. Bitte versuchen Sie es erneut.'),
                code='passwort_ungueltig',
            )
        return passwort

    def save(self, commit=True):
        user = self.user
        user.vorname = self.cleaned_data['vorname']
        user.nachname = self.cleaned_data['nachname']
        if commit:
            user.save()
        return user
