import secrets
import datetime
from django.db import models
from django.contrib.auth.models import AbstractBaseUser, BaseUserManager
from django.core.signing import Signer

SALT = 'W3VIvFmvhhvePbCmC_hcixstdpNRrjB5QqleEwvE2Uh00Mbi9VYfU-dixweZ3n1-e9JpkcHIw6XzCIZ_nefLqg'

# Create your models here.

class NutzerInManager(BaseUserManager):
    def _create_user(self, email, vorname, nachname, password, **extra_fields):
        if not email:
            raise ValueError('email address must be provided')
        if not password:
            raise ValueError('password must be provided')
        user = self.model(
            email=self.normalize_email(email),
            vorname=vorname,
            nachname=nachname,
            **extra_fields
        )
        user.set_password(password)
        user.save(using=self._db)
        return user

    def create_user(self, email, vorname, nachname, password=None, **extra_fields):
        extra_fields.setdefault('is_verwalter', False)
        return self._create_user(email, vorname, nachname, password, **extra_fields)

    def create_superuser(self, email, vorname, nachname, password=None, **extra_fields):
        extra_fields.setdefault('is_verwalter', True)
        return self._create_user(email, vorname, nachname, password, **extra_fields)

class NutzerIn(AbstractBaseUser):
    email = models.EmailField(
        max_length=255,
        unique=True
    )
    nachname = models.CharField(
        max_length=255
    )
    vorname = models.CharField(
        max_length=255
    )
    is_active = models.BooleanField(
        default=False
    )
    is_verwalter = models.BooleanField(
        default=False
    )

    USERNAME_FIELD = 'email'
    REQUIRED_FIELDS = ['nachname', 'vorname']
    EMAIL_FIELD = 'email'

    objects = NutzerInManager()

    @property
    def ist_active(self):
        return self.is_active

    @property
    def ist_verwalter(self):
        return self.is_verwalter

    @property
    def is_superuser(self):
        return self.is_verwalter

class NeueRNutzerInManager(models.Manager):
    def create(self, **kwargs):
        token = kwargs.get('token')
        if token is None:
            token = secrets.token_urlsafe(32)
            while self.filter(token=token).exists():
                token = secrets.token_urlsafe(32)
            kwargs['token'] = token
        return super().get_queryset().create(**kwargs)

    def bereinigt(self):
        abgelaufen = self.get_queryset().filter(
            ablauf_datum__lt=datetime.date.today()
        )
        if abgelaufen.exists():
            for eintrag in abgelaufen:
                eintrag.delete()
        return self.get_queryset()

    # raises django.core.signing.BadSignature
    def get_mit_signierten_token(self, signed_token):
        signer = Signer(sep='/', salt=SALT)
        token = signer.unsign(signed_token)
        return self.get_queryset().get(token=token)

class NeueRNutzerIn(models.Model):
    nutzer_in = models.OneToOneField(
        NutzerIn,
        on_delete=models.CASCADE,
        unique=True
    )
    token = models.SlugField(unique=True)
    ablauf_datum = models.DateField(
        default=datetime.date.today() + datetime.timedelta(days=21)
    )
    objects = NeueRNutzerInManager()

    def erneuern(self, commit=True):
        self.ablauf_datum = datetime.date.today() + datetime.timedelta(days=21)
        if commit:
            self.save(force_update=True)
        return self

    def generiere_signierten_link(self, erneuern=True):
        if erneuern:
            self.erneuern()
        return Signer(sep='/', salt=SALT).sign(self.token)

    def ist_abgelaufen(self):
        return self.ablauf_datum < datetime.date.today()
